<?php
/**
 * Cron Functions
 *
 * @package   rcp-group-accounts
 * @copyright Copyright (c) 2018, Restrict Content Pro team
 * @license   GPL2+
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * Set up the following cron job events:
 *
 * Daily: Remove accounts that haven't accepted group invitation
 * @see   rcpga_purge_unclaimed_invitations()
 *
 * @since 1.4
 * @return void
 */
function rcpga_setup_cron_jobs() {

	if ( ! wp_next_scheduled( 'rcpga_purge_unclaimed_invitations' ) ) {
		wp_schedule_event( current_time( 'timestamp' ), 'daily', 'rcpga_purge_unclaimed_invitations' );
	}

}

add_action( 'wp', 'rcpga_setup_cron_jobs' );

/**
 * Check for unclaimed invitations that are older than the defined period.
 * These invitations are deleted and the users are removed from the group.
 *
 * @since 1.4
 * @return void
 */
function rcpga_purge_unclaimed_invitations() {

	if ( function_exists( 'rcp_log' ) ) {
		rcp_log( 'Group Accounts: starting rcpga_purge_unclaimed_invitations() cron job.', true );
	}

	global $rcp_options;

	$period = ! empty( $rcp_options['groups_delete_pending_invites'] ) ? $rcp_options['groups_delete_pending_invites'] : 0;

	if ( empty( $period ) || '0' == $period ) {
		if ( function_exists( 'rcp_log' ) ) {
			rcp_log( 'Group Accounts: deleting pending invites is disabled - exiting rcpga_purge_unclaimed_invitations() cron job.', true );
		}

		return;
	}

	$number_removed = rcpga_group_accounts()->members->remove_unclaimed_invitations( $period );

	if ( function_exists( 'rcp_log' ) ) {
		rcp_log( sprintf( 'Group Accounts: found and removed %d expired invited members.', $number_removed ) );
	}

}

add_action( 'rcpga_purge_unclaimed_invitations', 'rcpga_purge_unclaimed_invitations' );