/* global rcpStripe, rcpStripeToggleElementErrors, rcp_stripe_script_options */

// Setup on page load.
( function() {
	var container = document.getElementById( 'rcp-card-wrapper' );

	if ( ! container ) {
		return;
	}

	container.innerHTML = '';

	// Need to dynamically generate a container to hold errors under the card field.
	var errorContainer = document.createElement( 'div' );
	errorContainer.id = 'rcp-card-element-errors';

	var cardContainer = document.createElement( 'div' );
	cardContainer.id = 'rcp-card-element';

	container.appendChild( cardContainer );
	container.appendChild( errorContainer );

	// Field is available, mount.
	rcpStripe.elements.card.mount( '#rcp-card-element' );

	// Handle errors.
	rcpStripe.elements.card.addEventListener( 'change', rcpStripeToggleElementErrors );
} )();

/**
 * Attempt to generate a token when the form is submitted.
 *
 * @param {Event} e Form submission event.
 */
function rcpStripeSubmitBillingCardUpdate( e ) {
	// Halt here.
	e.preventDefault();

	let cardHolderName = document.querySelector( '.rcp_card_name' ).value;
	let submitButton   = jQuery( '#rcp_submit' );
	let form           = jQuery( '#rcp_update_card_form' );

	submitButton.prop( 'disabled', true );

	form.block( {
		message: rcp_stripe_script_options.pleasewait,
		css: {
			border: 'none',
			padding: '15px',
			backgroundColor: '#000',
			'-webkit-border-radius': '10px',
			'-moz-border-radius': '10px',
			opacity: .5,
			color: '#fff'
		}
	} );

	/**
	 * Create a setup intent.
	 */
	jQuery.ajax( {
		type: 'post',
		dataType: 'json',
		url: rcp_stripe_script_options.ajaxurl,
		data: {
			action: 'rcp_stripe_create_setup_intent_for_saved_card',
			membership_id: jQuery( 'input[name="rcp_membership_id"]' ).val()
		},
		success: function ( response ) {
			if ( response.success ) {
				if ( 'payment_intent' === response.data.payment_intent_object ) {
					/*
					 * Payment Intent
					 * Handle a card payment.
					 */
					rcpStripe.Stripe.handleCardPayment(
						response.data.payment_intent_client_secret,
						rcpStripe.elements.card,
						{
							payment_method_data: {
								billing_details: {name: cardHolderName}
							}
						}
					).then( function( result ) {
						if ( result.error ) {
							rcpStripeHandleCardUpdateError( result.error.message );
						} else {
							// Success
							rcpStripeHandleCardUpdateSuccess( response );
						}
					} );
				} else {
					/*
					 * Setup Intent
					 * Handle a card setup.
					 */
					rcpStripe.Stripe.handleCardSetup(
						response.data.payment_intent_client_secret,
						rcpStripe.elements.card,
						{
							payment_method_data: {
								billing_details: {name: cardHolderName}
							}
						}
					).then( function( result ) {
						if ( result.error ) {
							rcpStripeHandleCardUpdateError( result.error.message );
						} else {
							// Success
							rcpStripeHandleCardUpdateSuccess( response );
						}
					} );
				}
			} else {
				rcpStripeHandleCardUpdateError( response.data );
			}
		}
	} );
}

/**
 * Handle card update success
 *      - Add `stripe_payment_intent_id` hidden field.
 *      - Add `stripe_payment_intent_object` hidden field.
 *
 * @param {object} response Ajax response.
 *
 * @since 3.2
 */
function rcpStripeHandleCardUpdateSuccess( response ) {
	let inputField = document.createElement( 'input' );
	inputField.value = response.data.payment_intent_id;
	inputField.type = 'hidden';
	inputField.name = 'stripe_payment_intent_id';

	form.appendChild( inputField );

	let objectField = document.createElement( 'input' );
	objectField.value = response.data.payment_intent_object;
	objectField.type = 'hidden';
	objectField.name = 'stripe_payment_intent_object';

	form.appendChild( objectField );

	// Re-submit form.
	form.removeEventListener( 'submit', rcpStripeSubmitBillingCardUpdate );
	form.submit();
}

/**
 * Handle card update failures
 *      - Show error message.
 *      - Re-enable submit button.
 *
 * @param {string} message Error message to display.
 *
 * @since 3.2
 */
function rcpStripeHandleCardUpdateError( message ) {

	jQuery( '#rcp_update_card_form' ).unblock();

	rcpStripeToggleElementErrors( {
		error: {
			message: message
		}
	} );

	jQuery( '#rcp_submit' ).prop( 'disabled', false );

}

var form = document.getElementById( 'rcp_update_card_form' );

form.addEventListener( 'submit', rcpStripeSubmitBillingCardUpdate );
