// Get bootstrapped data from the page.
var rcpStripe = window.rcpStripe || {};

// Configure Stripe API.
rcpStripe.Stripe = Stripe( rcpStripe.keys.publishable );

// Setup Elements.
rcpStripe.Elements = rcpStripe.Stripe.elements();
rcpStripe.elements = {
	card: rcpStripe.Elements.create( 'card', rcpStripe.elementsConfig ),
};

/**
 *
 * Handle form errors, given an error message.
 *
 * @param {string} message Error message.
 *
 * @since 3.2
 */
function rcpStripeHandleError( message ) {

	// If we're already on the registration form page or update billing card page, just show that error message.
	if ( document.getElementById( 'rcp_registration_form' ) || document.getElementById( 'rcp_update_card_form' ) ) {
		rcpStripeToggleElementErrors( {
			error: {
				message: message
			}
		} );
		rcpStripeEnableForm();
	} else if ( document.getElementById( 'rcp-stripe-confirm-form' ) ) {
		// We're on the confirmation page - show an inline error.
		jQuery( '#rcp-stripe-confirmation-loading' ).empty().append( rcpStripeGenerateNotice( message ) ).append( '<p><a href="' + document.referrer + '">' + rcp_script_options.click_try_again + '</a></p>' );
	}
}

/**
 * Generate a notice element.
 *
 * @param {string} message The notice text.
 * @return {Element} HTML element containing errors.
 */
function rcpStripeGenerateNotice( message ) {
	var span = document.createElement( 'span' );
	span.innerText = message;

	var notice = document.createElement( 'p' );
	notice.classList.add( 'rcp_error' );
	notice.appendChild( span );

	var wrapper = document.createElement( 'div' );
	wrapper.classList.add( 'rcp_message' );
	wrapper.classList.add( 'error' );
	wrapper.appendChild( notice );

	return wrapper;
}

/**
 * Show or hide errors based on input to the Card Element.
 *
 * @param {Event} event Change event on the Card Element.
 */
function rcpStripeToggleElementErrors( event ) {
	var errorContainer = document.getElementById( 'rcp-card-element-errors' );
	if ( null !== errorContainer ) {
		errorContainer.innerHTML = '';

		if ( event.error ) {
			errorContainer.appendChild( rcpStripeGenerateNotice( event.error.message ) );
		}
	}
}
